@@ -3,17 +3,22 @@
 import click
 import napari
 import xml.etree.ElementTree as ET
-from PIL import Image
 import numpy as np
-from viewmask.utils import (xml_to_contours,
-                            centers_of_contours,
-                            xml_to_image,
-                            get_stroke_color,
-                            mask_to_contours,
-                            centers_to_image)
+from viewmask.utils import (
+    file_to_dask_array,
+    xml_to_contours,
+    centers_of_contours,
+    xml_to_image,
+    get_stroke_color,
+    mask_to_contours,
+    centers_to_image
+)
 from os.path import splitext
 
 
+# TODO: eventually napari will rename is_pyramid to multiscale:
+# https://github.com/napari/napari/commit/1adff3e467768076643e8e02a12d4bf726f563a9
+
 INTERACTIVE_OPTION_HELP = 'If passed, the annotations will be rendered as ' + \
     'napari objects rather than rendered together and displayed as an image.'
 
@@ -35,7 +40,8 @@ def cli():
     show_default=True,
     type=bool,
     is_flag=True,
-    help=INTERACTIVE_OPTION_HELP)
+    help=INTERACTIVE_OPTION_HELP
+)
 def view_annotations(annotations, interactive):
     if splitext(annotations)[1] == '.npy' and interactive is True:
         raise ValueError(
@@ -66,16 +72,16 @@ def view_annotations(annotations, interactive):
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
+                    blending='additive',
                     is_pyramid=False,
-                    blending='additive'
                 )
             else:
                 rendered_annotations = xml_to_image(tree)
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
+                    blending='additive',
                     is_pyramid=False,
-                    blending='additive'
                 )
             centers = centers_of_contours(
                 mask_to_contours(rendered_annotations))
@@ -83,19 +89,17 @@ def view_annotations(annotations, interactive):
                 centers_to_image(centers),
                 name='centers',
                 rgb=True,
-                blending='additive'
+                blending='additive',
+                is_pyramid=False,
             )
 
 
 @cli.command(name='image')
 @click.argument('image', type=click.Path(exists=True, dir_okay=False))
 def view_image(image):
+    da_img = file_to_dask_array(image)
     with napari.gui_qt():
-        if splitext(image)[1] == '.npy':
-            np_img = np.load(image)
-        else:
-            np_img = np.array(Image.open(image))
-        _ = napari.view_image(np_img, name='image')
+        _ = napari.view_image(da_img, name='image', is_pyramid=False)
 
 
 @cli.command(name='overlay')
@@ -111,17 +115,23 @@ def view_image(image):
     help=INTERACTIVE_OPTION_HELP
 )
 def view_overlay(image, annotations, interactive):
+    # TODO: use assert?
+    # TODO: use annotations.endswith('.npy')?
     if splitext(annotations)[1] == '.npy' and interactive is True:
         raise ValueError(
             "The interactive flag cannot be passed with a numpy mask.")
 
+    da_img = file_to_dask_array(image)
+
     with napari.gui_qt():
         viewer = napari.Viewer()
-        if splitext(image)[1] == '.npy':
-            np_img = np.load(image)
-        else:
-            np_img = np.array(Image.open(image))
-        viewer.add_image(np_img, name='image', blending='additive')
+
+        viewer.add_image(
+            da_img,
+            name='image',
+            blending='additive',
+            is_pyramid=False,
+        )
 
         if interactive:
             tree = ET.parse(annotations)
@@ -142,8 +152,8 @@ def view_overlay(image, annotations, interactive):
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
+                    blending='additive',
                     is_pyramid=False,
-                    blending='additive'
                 )
             else:
                 tree = ET.parse(annotations)
@@ -151,8 +161,8 @@ def view_overlay(image, annotations, interactive):
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
+                    blending='additive',
                     is_pyramid=False,
-                    blending='additive'
                 )
             centers = centers_of_contours(
                 mask_to_contours(rendered_annotations))
@@ -160,7 +170,8 @@ def view_overlay(image, annotations, interactive):
                 centers_to_image(centers),
                 name='centers',
                 rgb=True,
-                blending='additive'
+                blending='additive',
+                is_pyramid=False,
             )
 
 
